@@ -1,8 +1,11 @@
 #![feature(if_let_guard)]
 use std::{fmt::Debug};
+pub use castle_query_parser::Input;
 pub use castle_query_parser::{Field, Inputs, Projection};
 pub use types::value::Value;
 
+pub use crate::castle::Castle;
+
 mod validation;
 pub mod castle;
 pub mod types;
